/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.vehicle;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.model.VehicleManager;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser
 */
@ServiceProvider(service = VehicleManager.class)
public class VehicleManagerImpl implements VehicleManager {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.vehicle");

    @Override
    public Vehicle load(FileObject fileObject) {
        Vehicle vehicle = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            vehicle = (Vehicle) ois.readObject();
        } catch (ClassNotFoundException | IOException | NullPointerException ex) {
            LOGGER.log(Level.WARNING, "Could not create vehicle from fileObject", ex.getMessage());
        }
        return vehicle;
    }

    @Override
    public void save(Vehicle vehicle, FileObject fileObject) {
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(vehicle);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
    }
}
