/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.vehicle.tree;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.nodes.Node;

/**
 *
 * @author Maciek Dulkiewicz & Wytse Visser
 */
@NodeFactory.Registration(projectType = "nl-cloudfarming-client-fleet")
public class VehicleCategoryNodeFactory implements NodeFactory {

    private static final String DIR_NAME = "Vehicles";
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.vehicle");

    @Override
    public NodeList<?> createNodes(Project project) {
        List<Node> nodes = new ArrayList<>();

        try {
            createDirectoryIfNotExists(project);
            nodes.add(new VehicleCategoryNode(project, new VehicleCategoryChildFactory(
                    getDirectory(project))));
        } catch (IOException ex) {
            LOGGER.log(Level.SEVERE, "Could not create subdirectory for vehicles", ex.getMessage());
        } finally {
            return NodeFactorySupport.fixedNodeList(nodes.toArray(new Node[nodes.size()]));
        }
    }

    private void createDirectoryIfNotExists(Project project) throws IOException {
        FileObject fleetProjectDir = project.getProjectDirectory();

        if (fleetProjectDir.getFileObject(DIR_NAME) == null) {
            fleetProjectDir.createFolder(DIR_NAME);
        }
    }

    public static FileObject getDirectory(Project project) {
        return project.getProjectDirectory().getFileObject(DIR_NAME);
    }
    
    public static String getDirectoryName() {
        return DIR_NAME;
    }
}
